[Xfce4-commits] [xfce/xfwm4] 04/07: compositor: Log which vsync mechanism is used

noreply at xfce.org noreply at xfce.org
Tue Aug 25 19:02:09 CEST 2015


This is an automated email from the git hooks/post-receive script.

olivier pushed a commit to branch master
in repository xfce/xfwm4.

commit f7f25d12a3f5205f4c0fb16e8bfccc74e05d1b78
Author: Olivier Fourdan <fourdan at xfce.org>
Date:   Tue Aug 25 16:54:39 2015 +0200

    compositor: Log which vsync mechanism is used
    
    Signed-off-by: Olivier Fourdan <fourdan at xfce.org>
---
 src/compositor.c |   16 +++++++++++++++-
 1 file changed, 15 insertions(+), 1 deletion(-)

diff --git a/src/compositor.c b/src/compositor.c
index 0a44426..4fb7bd4 100644
--- a/src/compositor.c
+++ b/src/compositor.c
@@ -4320,7 +4320,7 @@ compositorManageScreen (ScreenInfo *screen_info)
 #endif /* HAVE_EPOXY */
 
 #ifdef HAVE_PRESENT_EXTENSION
     /* Prefer present over glx if available (it's faster on my hardware) */
     screen_info->use_present = display_info->have_present && !screen_info->use_glx;
     if (screen_info->use_present)
     {
@@ -4333,6 +4333,20 @@ compositorManageScreen (ScreenInfo *screen_info)
     screen_info->use_present = FALSE;
 #endif /* HAVE_PRESENT_EXTENSION */
 
+    if (screen_info->use_glx)
+    {
+        DBG ("Compositor using GLX for vsync");
+    }
+    else if (screen_info->use_present)
+    {
+        DBG ("Compositor using XPresent for vsync");
+    }
+    else
+    {
+        g_warning ("No vsync support in compositor");
+    }
+
+
     XFixesSelectCursorInput (display_info->dpy,
                              screen_info->xroot,
                              XFixesDisplayCursorNotifyMask);
@@ -4320,7 +4320,7 @@ compositorManageScreen (ScreenInfo *screen_info)
 
 #ifdef HAVE_PRESENT_EXTENSION
-    /* Prefer present over glx if available (it's faster on my hardware) */
+    /* Prefer glx over xpresent if available */
     screen_info->use_present = display_info->have_present && !screen_info->use_glx;
     if (screen_info->use_present)

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list